intelmq.bots.parsers.html_table package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.parsers.html_table package

## Submodules

## intelmq.bots.parsers.html_table.parser module

HTML Table parser

Parameters: columns: string ignore_values: string skip_table_head: boolean attribute_name: string attribute_value: string table_index: int split_column: string split_separator: string split_index: int default_url_protocol: string time_format: string type: string

`intelmq.bots.parsers.html_table.parser.` `BOT`

  alias of `intelmq.bots.parsers.html_table.parser.HTMLTableParserBot`

class `intelmq.bots.parsers.html_table.parser.` `HTMLTableParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `init`()
  `process`()

## Module contents